package eta

import (
	"github.com/gin-gonic/gin"
	"github.com/go-playground/validator/v10"
	"hongze/hz_crm_eta/controller/resp"
	"hongze/hz_crm_eta/global"
	"hongze/hz_crm_eta/models/eta"
	etaService "hongze/hz_crm_eta/services/eta"
)

type ReportChapterTypeController struct{}

// YbSync
// @Title 同步报告章节小程序信息
// @Description 同步报告章节小程序信息
// @Param	request  body  eta.ReportChapterTypeSyncReq  true  "type json string"
// @Success 200 string "操作成功"
// @router /chapter_type/yb/sync [post]
func (this *ReportChapterTypeController) YbSync(c *gin.Context) {
	var req eta.ReportChapterTypeSyncReq
	err := c.Bind(&req)
	if err != nil {
		errs, ok := err.(validator.ValidationErrors)
		if !ok {
			resp.FailData("参数解析失败", "Err:"+err.Error(), c)
			return
		}
		resp.FailData("参数解析失败", errs.Translate(global.Trans), c)
		return
	}
	if req.ReportChapterTypeId <= 0 {
		resp.Fail("报告章节序号不能为空", c)
		return
	}
	e, msg := etaService.SyncReportChapterType(&req)
	if e != nil {
		resp.FailData(msg, e.Error(), c)
		return
	}

	resp.Ok("操作成功", c)
}

// RuleSync
// @Title 同步报告章节更新设置
// @Description 同步报告章节更新设置
// @Param	request  body  eta.ReportChapterTypeSyncReq  true  "type json string"
// @Success 200 string "操作成功"
// @router /chapter_type/rule/sync [post]
func (this *ReportChapterTypeController) RuleSync(c *gin.Context) {
	var req eta.ReportChapterTypeRuleSyncReq
	err := c.Bind(&req)
	if err != nil {
		errs, ok := err.(validator.ValidationErrors)
		if !ok {
			resp.FailData("参数解析失败", "Err:"+err.Error(), c)
			return
		}
		resp.FailData("参数解析失败", errs.Translate(global.Trans), c)
		return
	}
	e, msg := etaService.SyncReportChapterTypeUpdateRule(&req)
	if e != nil {
		resp.FailData(msg, e.Error(), c)
		return
	}
	resp.Ok("操作成功", c)
}
