package crm

import (
	"hongze/hz_crm_eta/global"
	"time"
)

type ChartPermission struct {
	ChartPermissionId     int       `gorm:"column:chart_permission_id;primary_key;AUTO_INCREMENT;NOT NULL;comment:'主键'" json:"chart_permission_id"`
	ChartPermissionName   string    `gorm:"column:chart_permission_name;default:NULL;comment:'名称'" json:"chart_permission_name"`
	PermissionName        string    `gorm:"column:permission_name;default:;comment:'权限名'" json:"permission_name"`
	Sort                  int       `gorm:"column:sort;default:1;comment:'排序'" json:"sort"`
	Enabled               int       `gorm:"column:enabled;comment:'是否可用 0禁用， 1启用'" json:"enabled"`
	CreatedTime           time.Time `gorm:"column:created_time;default:CURRENT_TIMESTAMP;comment:'创建时间'" json:"created_time"`
	LastUpdatedTime       time.Time `gorm:"column:last_updated_time;default:CURRENT_TIMESTAMP;NOT NULL" json:"last_updated_time"`
	TeleconferenceSort    int       `gorm:"column:teleconference_sort;default:0;comment:'电话会类型排序'" json:"teleconference_sort"`
	Remark                string    `gorm:"column:remark;default:NULL" json:"remark"`
	ClassifyName          string    `gorm:"column:classify_name;default:NULL" json:"classify_name"`
	ProductName           string    `gorm:"column:product_name;default:" json:"product_name"`
	ProductId             int       `gorm:"column:product_id;default:0" json:"product_id"`
	ImageUrl              string    `gorm:"column:image_url;default:NULL;comment:'图片地址'" json:"image_url"`
	ShowType              int       `gorm:"column:show_type;default:0;comment:'1:查研观向小程序展示'" json:"show_type"`
	IsOther               int       `gorm:"column:is_other;default:0;NOT NULL;comment:'是否是其他，用于查研观向小程序后台展示'" json:"is_other"`
	IsReport              int       `gorm:"column:is_report;default:0;NOT NULL;comment:'是否是报告，用于查研观向小程序前台报告展示'" json:"is_report"`
	CygxAuth              int       `gorm:"column:cygx_auth;default:0;NOT NULL;comment:'是否是权限，用于查研观向小程序前台权限校验'" json:"cygx_auth"`
	PermissionType        int       `gorm:"column:permission_type;default:0;NOT NULL;comment:'1主观，2客观'" json:"permission_type"`
	YbImgUrl              string    `gorm:"column:yb_img_url;default:NULL;comment:'研报小程序报告列表icon'" json:"yb_img_url"`
	ProductPermissionName string    `gorm:"column:product_permission_name;default:;comment:'种类权限名称'" json:"product_permission_name"`
	PriceDrivenState      int       `gorm:"column:price_driven_state;default:1;NOT NULL;comment:'品种价格驱动状态 0-关闭 1-开启'" json:"price_driven_state"`
	ImageUrlM             string    `gorm:"column:image_url_m;default:NULL;comment:'图片地址(查研观向移动端)'" json:"image_url_m"`
	ParentId              int       `gorm:"column:parent_id;default:0;NOT NULL;comment:'父级权限id'" json:"parent_id"`
	IsPublic              int       `gorm:"column:is_public;default:0;NOT NULL;comment:'是否是公有权限1:公有权限，0私有权限'" json:"is_public"`
}

func (c *ChartPermission) TableName() string {
	return "chart_permission"
}

// GetItemById 查询品种
func (c *ChartPermission) GetItemById(chartPermissionId int) (item *ChartPermission, err error) {
	err = global.MYSQL["hz_crm"].Where("chart_permission_id = ?", chartPermissionId).First(&item).Error
	return
}

// GetItemsByCondition 查询列表
func (c *ChartPermission) GetItemsByCondition(condition string, pars []interface{}) (items []*ChartPermission, err error) {
	err = global.MYSQL["hz_crm"].Where(condition, pars...).Order("sort asc, chart_permission_id asc").Find(&items).Error
	return
}

// GetItemByCondition 查询列表
func (c *ChartPermission) GetItemByCondition(condition string, pars []interface{}) (item *ChartPermission, err error) {
	err = global.MYSQL["hz_crm"].Where(condition, pars...).First(&item).Error
	return
}

// UpdateOrCreate 更新或者创建权限
func (c *ChartPermission) UpdateOrCreate() (err error) {
	// 保存记录，如果不存在则创建，存在则更新
	err = global.MYSQL["hz_crm"].Save(&c).Error
	return
}

type PermissionEnabledReq struct {
	ChartPermissionId int `description:"品种权限Id"`
	Enabled           int `description:"是否可用 0禁用， 1启用"`
}
