package crm

import "hongze/hz_crm_eta/global"

type ChartPermissionSearchKeyWordMapping struct {
	Id                 int    `gorm:"column:id;primary_key;AUTO_INCREMENT;NOT NULL"`
	ChartPermissionId  int    `gorm:"column:chart_permission_id;default:0"`
	KeyWord            string `gorm:"column:key_word;default:"`
	From               string `gorm:"column:from;default:"`
	TacticType         string `gorm:"column:tactic_type;default:;comment:'策略表type字段值'"`
	TeleconferenceSort int    `gorm:"column:teleconference_sort;default:0;comment:'电话会类型排序'"`
	ClassifyId         int    `gorm:"column:classify_id;default:0;comment:'报告分类ID'"`
}

func (c *ChartPermissionSearchKeyWordMapping) TableName() string {
	return "chart_permission_search_key_word_mapping"
}

type ClassifyPermissionReq struct {
	Keyword string
}

type ClassifyPermissionResp struct {
	List []*ChartPermissionSearchKeyWordMapping
}

func (c *ChartPermissionSearchKeyWordMapping) GetPermissionByKeyword(classifyNameSecond string) (items []*ChartPermissionSearchKeyWordMapping, err error) {
	err = global.MYSQL["hz_crm"].Where("`from`='rddp' AND key_word = ?", classifyNameSecond).Find(&items).Error
	return
}

func (c *ChartPermissionSearchKeyWordMapping) GetPermission() (items []*ChartPermissionSearchKeyWordMapping, err error) {
	err = global.MYSQL["hz_crm"].Where("`from`='rddp'").Find(&items).Error
	return
}

// ClassifyPermissionEditReq 编辑分类权限请求
type ClassifyPermissionEditReq struct {
	Keyword    string
	ClassifyId int
}

type PermissionKeywordReq struct {
	NewKeyword string
	ClassifyId int
}

// EditChartPermissionSearchKeyWordMappingMulti 修改报告报告权限（先删除原有的权限，再添加新的权限）
func (c *ChartPermissionSearchKeyWordMapping) EditChartPermissionSearchKeyWordMappingMulti(keyword string, permissionIdList []*ChartPermissionSearchKeyWordMapping, classifyId int) (err error) {
	tx := global.MYSQL["hz_crm"].Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()
	sql1 := "DELETE FROM chart_permission_search_key_word_mapping WHERE `from` = 'rddp' AND classify_id = ? "
	err = tx.Exec(sql1, classifyId).Error
	if err != nil {
		return
	}
	// 批量插入绑定的权限
	if len(permissionIdList) > 0 {
		err = tx.CreateInBatches(permissionIdList, 200).Error
	}
	return
}

// UpdateChartPermissionNameFromMappingByKeyword 根据关键词及来源更新新关键词
func UpdateChartPermissionNameFromMappingByKeyword(newKeyword string, classifyId int, source string) (err error) {
	sql := " UPDATE chart_permission_search_key_word_mapping SET key_word = ? WHERE key_word = ? AND `from` = ? "
	err = global.MYSQL["hz_crm"].Exec(sql, newKeyword, classifyId, source).Error
	return
}
