package crm

import (
	"hongze/hz_crm_eta/global"
	"time"
)

type ReportChapterTypePermission struct {
	Id                    int       `gorm:"column:id;primary_key;AUTO_INCREMENT;NOT NULL;comment:'自增序号'"`
	ReportChapterTypeId   int       `gorm:"column:report_chapter_type_id;NOT NULL;comment:'报告章节类型id'"`
	CreatedTime           time.Time `gorm:"column:created_time;default:CURRENT_TIMESTAMP;NOT NULL;comment:'创建时间'"`
	ChartPermissionId     int       `gorm:"column:chart_permission_id;NOT NULL;comment:'权限ID，对应chart_permission权限表'"`
	ResearchType          string    `gorm:"column:research_type;default:week;NOT NULL;comment:'研报类型：day：晨报，week：周报'"`
	PermissionName        string    `gorm:"column:permission_name;default:NULL;comment:'权限名称'"`
	ReportChapterTypeName string    `gorm:"column:report_chapter_type_name;default:NULL;comment:'章节名称'"`
}

func (r *ReportChapterTypePermission) TableName() string {
	return "report_chapter_type_permission"
}

// SetReportChapterTypePermission 设置报告章节类型权限
func SetReportChapterTypePermission(chapterTypeId int, researchType string, newPermissions []*ReportChapterTypePermission, newWeekPermissions []*ChartPermissionChapterMapping) (err error) {
	tx := global.MYSQL["hz_crm"].Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()

	// 章节类型权限调整
	{
		// 删除原章节类型权限
		sql := `DELETE FROM report_chapter_type_permission WHERE report_chapter_type_id = ? AND research_type = ?`
		err = tx.Exec(sql, chapterTypeId, researchType).Error
		if err != nil {
			return
		}

		// 新增章节类型权限
		if len(newPermissions) > 0 {
			err = tx.CreateInBatches(newPermissions, len(newPermissions)).Error
			if err != nil {
				return
			}
		}
	}

	// 周报章节调整chart_permission_chapter_mapping表
	//if researchType == utils.REPORT_TYPE_WEEK {
	//	// 删除原权限
	//	sql = `DELETE FROM chart_permission_chapter_mapping WHERE report_chapter_type_id = ? AND research_type = ?`
	//	err = tx.Exec(sql, chapterTypeId, researchType).Error
	//	if err != nil {
	//		return
	//	}
	//
	//	// 新增权限
	//	if len(newWeekPermissions) > 0 {
	//		err = tx.CreateInBatches(newWeekPermissions, len(newWeekPermissions)).Error
	//		if err != nil {
	//			return
	//		}
	//	}
	//}

	// 章节报告权限调整
	{
		// 删除原权限
		sql := `DELETE FROM chart_permission_chapter_mapping WHERE report_chapter_type_id = ? AND research_type = ?`
		err = tx.Exec(sql, chapterTypeId, researchType).Error
		if err != nil {
			return
		}

		// 新增权限
		if len(newWeekPermissions) > 0 {
			err = tx.CreateInBatches(newWeekPermissions, len(newWeekPermissions)).Error
			if err != nil {
				return
			}
		}
	}

	return
}

// GetChapterTypePermissionByTypeIdAndResearchType 根据章节类型ID及研报类型获取章节类型权限列表
func GetChapterTypePermissionByTypeIdAndResearchType(researchType string) (items []*ReportChapterTypePermission, err error) {
	err = global.MYSQL["hz_crm"].Model(ReportChapterTypePermission{}).Where("research_type = ?", researchType).Order("chart_permission_id ASC").Scan(&items).Error
	return
	return
}
