package eta

import (
	"fmt"
	"hongze/hz_crm_eta/global"
	"time"
)

type ReportChapterType struct {
	ReportChapterTypeId    int       `gorm:"column:report_chapter_type_id;primary_key;AUTO_INCREMENT;NOT NULL;comment:'报告章节类型id'"`
	ReportChapterTypeKey   string    `gorm:"column:report_chapter_type_key;default:NULL;comment:'章节key'"`
	ReportChapterTypeThumb string    `gorm:"column:report_chapter_type_thumb;default:NULL;comment:'H5展示的图片'"`
	BannerUrl              string    `gorm:"column:banner_url;default:NULL;comment:'banner显示图片'"`
	ReportChapterTypeName  string    `gorm:"column:report_chapter_type_name;default:NULL;comment:'报告章节类型名称'"`
	Sort                   int       `gorm:"column:sort;default:0;NOT NULL;comment:'排序字段'"`
	Enabled                int       `gorm:"column:enabled;default:NULL;comment:'报告类型状态'"`
	CreatedTime            time.Time `gorm:"column:created_time;default:CURRENT_TIMESTAMP;comment:'创建时间'"`
	LastUpdatedTime        time.Time `gorm:"column:last_updated_time;default:CURRENT_TIMESTAMP;NOT NULL"`
	ResearchType           string    `gorm:"column:research_type;default:week;comment:'研报类型'"`
	SelectedImage          string    `gorm:"column:selected_image;default:NULL;comment:'选中时的图片'"`
	UnselectedImage        string    `gorm:"column:unselected_image;default:NULL;comment:'没选中时的图片'"`
	PcSelectedImage        string    `gorm:"column:pc_selected_image;default:NULL;comment:'选中时的图片'"`
	PcUnselectedImage      string    `gorm:"column:pc_unselected_image;default:NULL;comment:'没选中时的图片'"`
	EditImgUrl             string    `gorm:"column:edit_img_url;default:NULL;comment:'管理后台编辑时选用的图'"`
	TickerTitle            string    `gorm:"column:ticker_title;default:NULL;comment:'指标列的标题'"`
	//IsShow                     int       `gorm:"column:is_show;default:1;comment:'是否显示'"`
	IsShow                     int    `gorm:"column:is_show;default:0;comment:'是否显示'"`
	PauseStartTime             string `gorm:"column:pause_start_time;default:NULL;comment:'暂停开始日期'"`
	PauseEndTime               string `gorm:"column:pause_end_time;default:NULL;comment:'暂停结束日期'"`
	IsSet                      int    `gorm:"column:is_set;default:0;comment:'是否设置:0为设置,1已设置'"`
	YbIconUrl                  string `gorm:"column:yb_icon_url;default:NULL;comment:'研报小程序3.0图标地址'"`
	YbBottomIcon               string `gorm:"column:yb_bottom_icon;default:NULL;comment:'研报小程序3.0底部菜单图标地址'"`
	YbHidden                   uint   `gorm:"column:yb_hidden;default:0;NOT NULL;comment:'研报小程序隐藏章节: 0-显示; 1-隐藏'"`
	ReportClassifyId           int    `description:"所属分类id"`
	InheritReportChapterTypeId int    `description:"继承的报告章节类型id"`
}

func (r *ReportChapterType) TableName() string {
	return "report_chapter_type"
}

type ChapterTypeReq struct {
	ReportType string
}

type ReportChapterTypeSyncReq struct {
	ReportChapterTypeId int `description:"报告章节类型id"`
}

type ReportChapterTypeRuleSyncReq struct {
	ReportClassifyId int `description:"研报分类id"`
}

// GetReportChapterType 获取章节类型列表
func GetReportChapterType(condition string, pars []interface{}) (items []*ReportChapterType, err error) {
	err = global.MYSQL["rddp"].Model(ReportChapterType{}).Where(condition, pars...).Order("sort ASC, created_time DESC").Scan(&items).Error
	return
}

// ReportChapterTypeListItem 章节类型列表信息
type ReportChapterTypeListItem struct {
	ReportChapterTypeId   int    `description:"报告章节类型id"`
	ReportChapterTypeName string `description:"报告章节类型名称"`
	Sort                  int    `description:"排序字段"`
	CreatedTime           string `description:"创建时间"`
	ResearchType          string `description:"研报类型"`
	SelectedImage         string `description:"选中时的图片"`
	UnselectedImage       string `description:"没选中时的图片"`
	WordsImage            string `description:"带字的icon"`
	EditImgUrl            string `description:"管理后台编辑时选用的图"`
	IsShow                int    `description:"显示隐藏: 1-显示; 0-隐藏"`
	Enabled               int
	ChartPermissionIdList []int `description:"权限id数组"`
}

// ReportChapterTypeAddReq 新增章节类型请求体
type ReportChapterTypeAddReq struct {
	ReportChapterTypeName string `description:"报告章节类型名称"`
	ResearchType          string `description:"研报类型"`
	ChartPermissionIdList []int  `description:"权限id数组"`
}

// ReportChapterTypeEditReq 编辑章节类型请求体
type ReportChapterTypeEditReq struct {
	ReportChapterTypeId   int    `description:"报告章节类型id"`
	ReportChapterTypeName string `description:"报告章节类型名称"`
	ResearchType          string `description:"研报类型"`
	ChartPermissionIdList []int  `description:"权限id数组"`
}

// ReportChapterTypeEditResp 编辑章节返回
type ReportChapterTypeEditResp struct {
	OriginReportChapterTypeName string `description:"报告章节类型原来的名称"`
}

// GetReportChapterTypeByCondition 获取章节类型
func (r *ReportChapterType) GetReportChapterTypeByCondition(condition string, pars []interface{}) (items []*ReportChapterType, err error) {
	err = global.MYSQL["rddp"].Model(ReportChapterType{}).Where(condition, pars...).Scan(&items).Error
	return
}

type ReportChapterTypeListResp struct {
	List []*ReportChapterTypeListItem
}

// Create 新增权限
func (r *ReportChapterType) Create() (err error) {
	err = global.MYSQL["rddp"].Create(r).Error
	return
}

// Update 更新权限
func (r *ReportChapterType) Update(cols []string) (err error) {
	err = global.MYSQL["rddp"].Model(r).Select(cols).Updates(r).Error
	return
}

// SetEnabled 更新启动禁用
func (r *ReportChapterType) SetEnabled(id, enabled int) (err error) {
	err = global.MYSQL["rddp"].Model(r).Where("report_chapter_type_id = ?", id).Update("enabled", enabled).Error
	return
}

// GetReportChapterTypeById 获取章节类型
func (r *ReportChapterType) GetReportChapterTypeById(reportChapterTypeId int) (item *ReportChapterType, err error) {
	err = global.MYSQL["rddp"].Model(r).Where("report_chapter_type_id = ?", reportChapterTypeId).First(&item).Error
	return
}

// GetMaxSort 获取最大的排序值
func (r *ReportChapterType) GetMaxSort() (maxSort int, err error) {
	err = global.MYSQL["rddp"].Model(r).Select("max(sort)").Scan(&maxSort).Error
	return
}

// GetMaxSortByResearchType 获取最大的排序值
func (r *ReportChapterType) GetMaxSortByResearchType(researchType string) (maxSort int, err error) {
	err = global.MYSQL["rddp"].Model(r).Select("max(sort)").Where("research_type = ?", researchType).Scan(&maxSort).Error
	return
}

type ReportChapterTypeEnabledReq struct {
	ReportChapterTypeId int `description:"报告章节类型id"`
	Enabled             int `description:"是否可用，1可用，0禁用"`
}

type ReportChapterTypeMoveReq struct {
	ReportChapterTypeId int `description:"报告章节类型id"`
	//	ParentChartPermissionId int `description:"父级品种id"`
	PrevReportChapterTypeId int `description:"上一个兄弟节点报告章节类型id"`
	NextReportChapterTypeId int `description:"下一个兄弟节点报告章节类型id"`
}

// UpdateReportChapterTypeSortByResearchType 根据父类id更新排序
func UpdateReportChapterTypeSortByResearchType(researchType string, reportChapterTypeId, nowSort int, updateSort string) (err error) {
	sql := ` update report_chapter_type set sort = ` + updateSort + ` WHERE research_type=? AND sort > ?`
	if reportChapterTypeId > 0 {
		sql += ` or ( report_chapter_type_id > ` + fmt.Sprint(reportChapterTypeId) + ` and sort = ` + fmt.Sprint(nowSort) + `)`
	}
	err = global.MYSQL["rddp"].Exec(sql, researchType, nowSort).Error
	return
}

// GetFirstReportChapterTypeByParentId 获取当前父级分类下，且排序数相同 的排序第一条的数据
func (r *ReportChapterType) GetFirstReportChapterTypeByResearchType(researchType string) (item *ReportChapterType, err error) {
	err = global.MYSQL["rddp"].Where("research_type = ?", researchType).Order("sort asc, report_chapter_type_id asc").First(&item).Error
	return
}

// UpdateOrCreate 更新或者编辑章节
func (r *ReportChapterType) UpdateOrCreate() (err error) {
	// 保存记录，如果不存在则创建，存在则更新
	err = global.MYSQL["rddp"].Save(&r).Error
	return
}
