package crm

import (
	"fmt"
	"hongze/hz_crm_eta/models/crm"
	"hongze/hz_crm_eta/models/eta"
)

// SyncReportChapterType  同步报表章节类型
func SyncReportChapterType(req *crm.ReportChapterTypeSyncReq) (err error, errMsg string) {
	//查询是否存在品种
	etaOb := new(eta.ReportChapterType)
	list, e := etaOb.GetReportChapterTypeByCondition("", []interface{}{})
	if e != nil {
		errMsg = "查询章节信息失败"
		err = fmt.Errorf("查询章节信息失败, Err: " + e.Error())
		return
	}
	//crmObj := crm.ReportChapterType{}
	for _, v := range list {
		ob := &crm.ReportChapterType{
			ReportChapterTypeId:        v.ReportChapterTypeId,
			ReportChapterTypeKey:       v.ReportChapterTypeKey,
			ReportChapterTypeThumb:     v.ReportChapterTypeThumb,
			BannerUrl:                  v.BannerUrl,
			ReportChapterTypeName:      v.ReportChapterTypeName,
			Sort:                       v.Sort,
			Enabled:                    v.Enabled,
			CreatedTime:                v.CreatedTime,
			LastUpdatedTime:            v.LastUpdatedTime,
			ResearchType:               v.ResearchType,
			SelectedImage:              v.SelectedImage,
			UnselectedImage:            v.UnselectedImage,
			PcSelectedImage:            v.PcSelectedImage,
			PcUnselectedImage:          v.PcUnselectedImage,
			EditImgUrl:                 v.EditImgUrl,
			TickerTitle:                v.TickerTitle,
			IsShow:                     v.IsShow,
			PauseStartTime:             v.PauseStartTime,
			PauseEndTime:               v.PauseEndTime,
			IsSet:                      v.IsSet,
			YbIconUrl:                  v.YbIconUrl,
			YbBottomIcon:               v.YbBottomIcon,
			YbHidden:                   v.YbHidden,
			ReportClassifyId:           v.ReportClassifyId,
			InheritReportChapterTypeId: v.InheritReportChapterTypeId,
		}

		//if v.ReportChapterTypeId >= 157 {
		//	fmt.Println("a")
		//}
		//_, tmpErr := crmObj.GetReportChapterTypeById(v.ReportChapterTypeId)
		//if tmpErr != nil {
		//	if errors.Is(tmpErr, utils.ErrNoRow) {
		//		err = ob.Create()
		//	}
		//} else {
		//	err = ob.Update([]string{"ReportChapterTypeThumb","BannerUrl","Sort","Enabled","CreatedTime","LastUpdatedTime","ResearchType","SelectedImage","UnselectedImage","PcSelectedImage","PcUnselectedImage","EditImgUrl","TickerTitle","IsShow","PauseStartTime","IsSet","YbIconUrl","YbBottomIcon","YbHidden","ReportClassifyId","InheritReportChapterTypeId"})
		//}
		//
		err = ob.UpdateOrCreate()
		if err != nil {
			errMsg = "更新失败"
			err = fmt.Errorf("更新章节类型失败, Err: " + err.Error())
			return
		}
	}

	if req.ReportChapterTypeId > 0 {
		if req.ResearchType == `` {
			req.ResearchType = "chapter"
		}
		//同步权限信息
		newPermissions := make([]*crm.ReportChapterTypePermission, 0)       // 报告章节权限表(新)
		newWeekPermissions := make([]*crm.ChartPermissionChapterMapping, 0) // 报告章节权限表(老)
		newEtaPermissions, er := eta.GetChapterTypePermissionByTypeIdAndResearchType(req.ReportChapterTypeId)
		if er != nil {
			errMsg = "更新失败"
			err = fmt.Errorf("查询章节权限失败, Err: " + er.Error())
			return
		}
		for _, v := range newEtaPermissions {
			tmp := &crm.ReportChapterTypePermission{
				ReportChapterTypeId:   v.ReportChapterTypeId,
				CreatedTime:           v.CreatedTime,
				ChartPermissionId:     v.ChartPermissionId,
				ResearchType:          v.ResearchType,
				PermissionName:        v.PermissionName,
				ReportChapterTypeName: v.ReportChapterTypeName,
			}
			newPermissions = append(newPermissions, tmp)
		}
		newWeekEtaPermissions, er := eta.GetChapterTypeMappingByTypeIdAndResearchType(req.ReportChapterTypeId, req.ResearchType)
		if er != nil {
			errMsg = "更新失败"
			err = fmt.Errorf("查询章节权限失败, Err: " + er.Error())
			return
		}
		for _, v := range newWeekEtaPermissions {
			tmp := &crm.ChartPermissionChapterMapping{
				ChartPermissionId:   v.ChartPermissionId,
				ReportChapterTypeId: v.ReportChapterTypeId,
				ResearchType:        v.ResearchType,
			}
			newWeekPermissions = append(newWeekPermissions, tmp)
		}

		err = crm.SetReportChapterTypePermission(req.ReportChapterTypeId, req.ResearchType, newPermissions, newWeekPermissions)
		if err != nil {
			errMsg = "更新失败"
			err = fmt.Errorf("设置章节类型权限失败, Err: " + er.Error())
			return
		}
	}
	return
}
