package eta

import (
	"fmt"
	"hongze/hz_crm_eta/models/crm"
	"hongze/hz_crm_eta/models/eta"
	"hongze/hz_crm_eta/utils"
)

// SyncReportChapterType  同步报表章节类型
func SyncReportChapterType(req *eta.ReportChapterTypeSyncReq) (err error, errMsg string) {
	//查询是否存在品种
	etaOb := new(crm.ReportChapterType)
	item, e := etaOb.GetReportChapterTypeById(req.ReportChapterTypeId)
	if e != nil {
		if e == utils.ErrNoRow {
			err = fmt.Errorf("章节不存在")
			return
		}
		errMsg = "查询章节信息失败"
		err = fmt.Errorf("查询章节信息失败, Err: " + e.Error())
		return
	}
	if item.ReportChapterTypeId <= 0 {
		err = fmt.Errorf("章节不存在")
		return
	}
	ob := &eta.ReportChapterType{
		ReportChapterTypeId: item.ReportChapterTypeId,
		//ReportChapterTypeKey:   item.ReportChapterTypeKey,
		ReportChapterTypeThumb: item.ReportChapterTypeThumb,
		BannerUrl:              item.BannerUrl,
		/*ReportChapterTypeName:  item.ReportChapterTypeName,
		Sort:                   item.Sort,
		Enabled:                item.Enabled,
		CreatedTime:            item.CreatedTime,
		LastUpdatedTime:        item.LastUpdatedTime,
		ResearchType:           item.ResearchType,*/
		SelectedImage:     item.SelectedImage,
		UnselectedImage:   item.UnselectedImage,
		PcSelectedImage:   item.PcSelectedImage,
		PcUnselectedImage: item.PcUnselectedImage,
		EditImgUrl:        item.EditImgUrl,
		//	TickerTitle:            item.TickerTitle,
		IsShow: item.IsShow,
		//PauseStartTime:         item.PauseStartTime,
		//PauseEndTime:           item.PauseEndTime,
		//IsSet:                  item.IsSet,
		YbIconUrl:    item.YbIconUrl,
		YbBottomIcon: item.YbBottomIcon,
		//YbHidden:               item.YbHidden,
	}

	updateCols := []string{"SelectedImage", "UnselectedImage",
		"PcSelectedImage", "PcUnselectedImage", "EditImgUrl", "YbIconUrl", "YbBottomIcon", "IsShow",
		"ReportChapterTypeThumb", "BannerUrl",
	}
	err = ob.Update(updateCols)
	if err != nil {
		errMsg = "更新失败"
		err = fmt.Errorf("更新章节类型失败, Err: " + err.Error())
		return
	}
	return
}

// SyncReportChapterTypeUpdateRule  同步报表章节类型更新设置
func SyncReportChapterTypeUpdateRule(req *eta.ReportChapterTypeRuleSyncReq) (err error, errMsg string) {
	//查询是否存在品种
	crmOb := new(crm.ReportChapterType)
	cond := ""
	pars := make([]interface{}, 0)
	if req.ReportClassifyId > 0 {
		cond += " report_classify_id = ? "
		pars = append(pars, req.ReportClassifyId)
	}

	list, e := crmOb.GetReportChapterTypeByCondition(cond, pars)
	if e != nil {
		errMsg = "查询章节信息失败"
		err = fmt.Errorf("查询章节信息失败, Err: " + e.Error())
		return
	}
	for _, v := range list {
		ob := &eta.ReportChapterType{
			ReportChapterTypeId: v.ReportChapterTypeId,
			/*ReportChapterTypeKey:   v.ReportChapterTypeKey,
			ReportChapterTypeThumb: v.ReportChapterTypeThumb,
			BannerUrl:              v.BannerUrl,
			ReportChapterTypeName:  v.ReportChapterTypeName,
			Sort:                   v.Sort,
			Enabled: v.Enabled,
			CreatedTime:            v.CreatedTime,
			LastUpdatedTime:        v.LastUpdatedTime,
			ResearchType:           v.ResearchType,
			SelectedImage:          v.SelectedImage,
			UnselectedImage:        v.UnselectedImage,
			PcSelectedImage:        v.PcSelectedImage,
			PcUnselectedImage:      v.PcUnselectedImage,
			EditImgUrl:             v.EditImgUrl,
			TickerTitle:            v.TickerTitle,
			IsShow:                 v.IsShow,*/
			PauseStartTime: v.PauseStartTime,
			PauseEndTime:   v.PauseEndTime,
			IsSet:          v.IsSet,
			/*YbIconUrl:              v.YbIconUrl,
			YbBottomIcon:           v.YbBottomIcon,
			YbHidden:               v.YbHidden,*/
		}

		updateCols := []string{"PauseStartTime", "PauseEndTime",
			"IsSet",
		}
		err = ob.Update(updateCols)
		if err != nil {
			errMsg = "更新失败"
			err = fmt.Errorf("更新章节类型 更新设置失败, Err: " + err.Error())
			return
		}
	}
	return
}
